@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2009 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "puzzletablewidget.h"
 #include "loadingwidget.h"
@@ -37,9 +25,9 @@ namespace Palapeli
 	class TextProgressBar : public QProgressBar
 	{
 		public:
-			TextProgressBar(QWidget* parent = 0) : QProgressBar(parent) {}
+			TextProgressBar(QWidget* parent = nullptr) : QProgressBar(parent) {}
 
-			QString text() const Q_DECL_OVERRIDE { return m_text; }
+			QString text() const override { return m_text; }
 			void setText(const QString& text) { m_text = text; update(); }
 		private:
 			QString m_text;
